@@ -1,11 +1,8 @@
 use crate::{SmartString, SmartStringMode};
-use alloc::{
-    boxed::Box,
-    string::{String, ToString},
-};
+use alloc::string::String;
 use arbitrary::{Arbitrary, Result, Unstructured};
 
-impl<Mode: SmartStringMode> Arbitrary for SmartString<Mode>
+impl<'a, Mode: SmartStringMode> Arbitrary<'a> for SmartString<Mode>
 where
     Mode: 'static,
 {
@@ -20,8 +17,4 @@ where
     fn size_hint(depth: usize) -> (usize, Option<usize>) {
         String::size_hint(depth)
     }
-
-    fn shrink(&self) -> Box<dyn Iterator<Item = Self>> {
-        Box::new(self.to_string().shrink().map(Self::from))
-    }
 }
