@@ -2,8 +2,10 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+use alloc::string::String;
 use core::cmp::Ordering;
 
+#[allow(unreachable_pub)]
 pub trait BoxedString {
     fn string(&self) -> &String;
     fn string_mut(&mut self) -> &mut String;
