@@ -526,19 +526,6 @@ mod tests {
 
     #[test]
     fn string_layout_consistency_check() {
-        let mut s = String::with_capacity(5);
-        s.push_str("lol");
-        assert_eq!(3, s.len());
-        assert_eq!(5, s.capacity());
-        let ptr: *const String = &s;
-        let ptr: *const usize = ptr.cast();
-        let first_bytes = unsafe { *ptr };
-        assert_ne!(3, first_bytes);
-        assert_ne!(5, first_bytes);
-        let first_byte = unsafe { *(ptr as *const u8) };
-        #[cfg(target_endian = "little")]
-        assert_eq!(0, first_byte & 0x01);
-        #[cfg(target_endian = "big")]
-        assert_eq!(0, first_byte & 0x80);
+        crate::validate();
     }
 }
